using System;
using System.Collections;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Runtime.Serialization;
using System.Text;
using System.Windows.Forms;
using System.Windows.Forms.Design;

using Syncfusion.Diagnostics;
using Syncfusion.Drawing;
using Syncfusion.Styles;
using Syncfusion.Windows.Forms;
using Syncfusion.Windows.Forms.Grid;

namespace ColorEdit_TransparentDemo
{
	[Serializable]
	public class GridDropDownColorUICellModel1: GridDropDownCellModel
	{
		public GridDropDownColorUICellModel1(GridModel grid)
			: base(grid)
		{
			AllowFloating = false;
			ButtonBarSize = new Size(21, 0);
		}

		protected GridDropDownColorUICellModel1(SerializationInfo info, StreamingContext context)
			: base(info, context)
		{

		}

		public override GridCellRendererBase CreateRenderer(GridControlBase control)
		{
			return new GridDropDownColorUICellRenderer1(control, this);
		}
	}

	public class GridDropDownColorUICellRenderer1: GridDropDownCellRenderer
	{
		ColorUIControl colorUI;
		string color = "white";
		public GridDropDownColorUICellRenderer1(GridControlBase grid, GridCellModelBase cellModel)
			: base(grid, cellModel)
		{
			DropDownButton = new GridCellButton(this);
			DropDownButton.Text = "@";
		}

		protected /*internal*/ override void InitializeDropDownContainer()
		{
			base.InitializeDropDownContainer();

			colorUI = new ColorUIControl();
			colorUI.Dock = DockStyle.Fill;
			colorUI.Visible = true;
			colorUI.ColorSelected += new EventHandler(ColorUIColorSelected);

			this.DropDownContainer.Controls.Add(colorUI);
		}

	
		public override void DropDownContainerShowingDropDown(object sender, CancelEventArgs e)
		{
			this.DropDownContainer.Size = new Size(500, 500);

			Size size = new Size(208,230);
			GridCurrentCellShowingDropDownEventArgs ce = new GridCurrentCellShowingDropDownEventArgs(size);
			Grid.RaiseCurrentCellShowingDropDown(ce);
			if (ce.Cancel)
			{
				e.Cancel = true;
				return;
			}
			this.DropDownContainer.Size = ce.Size;
		}


		public override void DropDownContainerShowedDropDown(object sender, EventArgs e)
		{
			DropDownContainer.FocusParent();
			NotifyShowedDropDown();
		}

		public override void OnPrepareViewStyleInfo(GridPrepareViewStyleInfoEventArgs e)
		{
			try
			{
				Color color = ColorConvert.ColorFromString(e.Style.Text);
				e.Style.Interior = new BrushInfo(color);
   			}
			catch (Exception ex)
			{
				TraceUtil.TraceExceptionCatched(ex);
				if (!ExceptionManager.RaiseExceptionCatched(this, ex))
					throw ex;
			}
		}

		public override void ChildClosing(IPopupChild childUI, PopupCloseType popupCloseType)
		{
			if (popupCloseType == PopupCloseType.Done && !IsReadOnly())
			{
				if (!this.NotifyCurrentCellChanging())
					return;

				    this.color = ColorConvert.ColorToString(colorUI.SelectedColor, true);
    				this.NotifyCurrentCellChanged();
			}
			DropDownContainerCloseDropDown(childUI, new PopupClosedEventArgs(popupCloseType));
			Grid.InvalidateRange(GridRangeInfo.Cell(RowIndex, ColIndex));
			CurrentCell.Renderer.ControlText = this.color;
			CurrentCell.EndEdit();
		}

		void ColorUIColorSelected(object sender, EventArgs e)
		{
			CurrentCell.CloseDropDown(PopupCloseType.Done);
		}
	}
}
